ReadBarcodeProps class

A class that is used to store the data that is passed to the ReadBarcode widget.

Constructors

ReadBarcodeProps(File? file)

Properties

file ↔ File?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onRequiredPassword ↔ Future<String> Function()?
getter/setter pair
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ num?
getter/setter pair
sequenceNum ↔ num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited