BarcodeReaderWebassemblyJsProps class

It's a Dart class that contains a single property, barcodeReaderJs, which is a JavaScript object

Annotations
  • @JS.new('BarcodeReaderWebassemblyJsProps')
  • @anonymous

Properties

filePath ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ num?
getter/setter pair
sequenceNum ↔ num?
getter/setter pair
wasmPath ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited